@@ -428,6 +428,7 @@ public:
 		AUDIO_STOP,
 		DTMF_GENDOWN,	/* peer */
 		DTMF_GENUP,	/* peer */
+		AUDIO_SYNC,	/* peer */
 		DTMF_GENTONE = DTMF_GENUP,
 
 		// make modes and special timeslot stuff
@@ -1776,6 +1777,22 @@ public:
 	 */
 	virtual bool isExternal(const char *dest);
 
+	/**
+	 * See if a given potential dialed number is registered
+	 *
+	 * @return true if extern and registered.
+	 * @param destination to test.
+	 */
+	virtual bool isRegistered(const char *dest);
+
+	/**
+	 * See if a given potential dialed number is available
+	 *
+	 * @return true if extern and available.
+	 * @param destination to test.
+	 */
+	virtual bool isAvailable(const char *dest);
+
 	/**
 	 * See if a given selected server is currently considered
 	 * reachable.  This could be used for failover.
@@ -1916,6 +1933,8 @@ private:
 protected:
 	virtual const char *submit(const char **data);
 
+	virtual ScriptCompiler *compiler(void);
+
 	BayonneSession *session(ScriptInterp *interp);
 
 	bool scriptEvent(ScriptInterp *interp, const char *evt);
@@ -1926,6 +1945,8 @@ protected:
 
 public:
 	static const char *submitRequest(const char **data);
+
+	static ScriptCompiler *getCompiler(void);
 };
 
 /**
