@@ -85,6 +85,16 @@ bool BayonneDriver::isExternal(const char *ext)
 	return false;
 }
 
+bool BayonneDriver::isRegistered(const char *ext)
+{
+	return isExternal(ext);
+}
+
+bool BayonneDriver::isAvailable(const char *ext)
+{
+	return isExternal(ext);
+}
+
 bool BayonneDriver::isReachable(const char *proxy)
 {
 	return true;
