@@ -196,8 +196,8 @@ bool Session::enterPickup(Event *event)
 		}
 		if(!driver->getPickupTimer())
 		{
-			setRunning();
-			return true;
+			event->id = TIMER_EXPIRED;
+			return false;
 		}
 		startTimer(driver->getPickupTimer());
 		return true;
