@@ -353,6 +353,94 @@ bool Driver::isExternal(const char *ext)
 	return rtn;
 }
 
+
+
+bool Driver::isRegistered(const char *ext)
+{
+	char buf[65];
+	ScriptImage *img;
+	Registry *reg;
+	bool rtn = false;
+	Name *scr;
+
+	if(!ext)
+		return false;
+
+	if(strchr(ext, '@'))
+		return false;
+
+	img = useImage();
+	if(!img)
+		return false;
+
+	if(!strnicmp(ext, "sip:", 4))
+		ext += 4;
+
+	snprintf(buf, sizeof(buf), "uri.%s", ext);
+	reg = (Registry *)img->getPointer(buf);
+	if(!reg)
+	{
+		snprintf(buf, sizeof(buf), "sip::%s", ext);
+		scr = img->getScript(buf);
+		if(scr && scr->select)
+		{
+			snprintf(buf, sizeof(buf), "uri.%s", scr->select->args[0]);
+			reg = (Registry *)img->getPointer(buf);
+		}
+	}
+	if(reg && !strnicmp(reg->type, "ext", 3))
+		rtn = reg->isActive();
+	endImage(img);
+	return rtn;
+}
+
+
+bool Driver::isAvailable(const char *ext)
+{
+	char buf[65];
+	ScriptImage *img;
+	Registry *reg;
+	bool rtn = false;
+	Name *scr;
+
+	if(!ext)
+		return false;
+
+	if(strchr(ext, '@'))
+		return false;
+
+	img = useImage();
+	if(!img)
+		return false;
+
+	if(!strnicmp(ext, "sip:", 4))
+		ext += 4;
+
+	snprintf(buf, sizeof(buf), "uri.%s", ext);
+	reg = (Registry *)img->getPointer(buf);
+	if(!reg)
+	{
+		snprintf(buf, sizeof(buf), "sip::%s", ext);
+		scr = img->getScript(buf);
+		if(scr && scr->select)
+		{
+			snprintf(buf, sizeof(buf), "uri.%s", scr->select->args[0]);
+			reg = (Registry *)img->getPointer(buf);
+		}
+	}
+	if(reg && !strnicmp(reg->type, "ext", 3) && reg->isActive())
+	{
+		if(!reg->call_limit)
+			rtn = true;
+		else if(reg->call_limit > reg->active_calls)
+			rtn = true;
+	}
+	endImage(img);
+	return rtn;
+}
+
+
+
 unsigned Driver::getRegistration(regauth_t *data, unsigned count)
 {
 	unsigned idx = 0;
