@@ -195,6 +195,9 @@ bool Session::enterJoin(Event *event)
 
 	switch(event->id)
 	{
+	case AUDIO_SYNC:
+		rtp->syncAudio();
+		return true;
 	case AUDIO_IDLE:
 		rtp->setTone(NULL);
 		return true;
