@@ -17,21 +17,15 @@
 #include "module.h"
 #include <cc++/process.h>
 
-namespace module {
+namespace moduleTCP {
 using namespace ost;
 using namespace std;
 
-#ifdef  WIN32
-#define KEYS    "/bayonne/tcpmon"
-#else
-#define KEYS    "/bayonne/module/tcpmon"
-#endif
-
 Service Service::tcp;
 bool Service::active = false;
 
 Service::Service() :
-BayonneService(0, 0), Keydata(Bayonne::getKeypath(KEYS))
+BayonneService(0, 0), Keydata("/bayonne/module/tcpmon")
 {
 	static Keydata::Define defkeys[] = {
 	{"interface", "127.0.0.1"},
@@ -39,19 +33,10 @@ BayonneService(0, 0), Keydata(Bayonne::getKeypath(KEYS))
 	{"secret", "pass"},
 	{NULL, NULL}};
 
-	load(defkeys);
-
-#ifdef  WIN32
-        const char *env = Process::getEnv("MODULECONFIG");
-
-        if(env)
-                loadFile(env, "tcpmon");
-#else
-	if(Bayonne::provision_system)
-		load("/bayonne/provision/tcpmon");
-	else if(Bayonne::provision_user)
+	if(Bayonne::getUserdata())
 	        load("~bayonne/tcpmon");
-#endif
+
+	load(defkeys);
 
 }
 
