@@ -183,6 +183,11 @@ ScriptThread(interp, 0)
 	paths = list;
 	completed = false;
 	dest = setString(destname, sizeof(destname), d);
+
+#ifdef	AUDIO_RATE_RESAMPLER
+	resampler = NULL;
+	resample = NULL;
+#endif
 }
 
 BuildThread::~BuildThread()
@@ -207,6 +212,17 @@ BuildThread::~BuildThread()
 	if(lbuffer)
 		delete[] lbuffer;
 
+#ifdef	AUDIO_RATE_RESAMPLER
+	if(resampler)
+		delete resampler;
+
+	if(resample)
+		delete[] resample;
+
+	resampler = NULL;
+	resample = NULL;
+#endif
+
 	in = NULL;
 	buffer = NULL;
 	lbuffer = NULL;
@@ -232,7 +248,7 @@ void BuildThread::run(void)
 	in->getInfo(&from);
 	Thread::yield();
 
-	if(to.encoding == from.encoding)
+	if(to.encoding == from.encoding && to.rate == from.rate)
 		copyDirect();
 	else
 	{
@@ -273,9 +289,10 @@ void BuildThread::copyDirect(void)
 
 void BuildThread::copyConvert(void)
 {
-	unsigned long samples;
+	unsigned long samples, copied;
 	unsigned pages, npages;
 	bool mono = true;
+	Linear source;
 
 	if(isStereo(from.encoding) || isStereo(to.encoding))
 		mono = false;
@@ -287,6 +304,16 @@ void BuildThread::copyConvert(void)
 	else
 		lbuffer = new Sample[samples * 2];
 
+	source = lbuffer;
+#ifdef	AUDIO_RATE_RESAMPLER
+	if(from.rate != to.rate)
+	{
+		resampler = new AudioResample((Rate)from.rate, (Rate)to.rate);
+		resample = new Sample[resampler->estimate(samples)];
+		source = resample;
+	}
+#endif
+
 	for(;;)
 	{
 		Thread::yield();
@@ -300,10 +327,16 @@ void BuildThread::copyConvert(void)
 
 		Thread::yield();
 
+		copied = samples;
+#ifdef	AUDIO_RATE_RESAMPLER
+		if(resampler)
+			copied = resampler->process(lbuffer, resample, samples);
+#endif
+
 		if(mono)
-			npages = out.bufMono(lbuffer, samples);
+			npages = out.bufMono(source, copied);
 		else
-			npages = out.bufStereo(lbuffer, samples);
+			npages = out.bufStereo(source, copied);
 	}
 	completed = true;
 }
